@@ -1,21 +1,9 @@
 import os
 import igraph
-from math import radians, cos, sin, asin, sqrt
+from geo import haversine
 
 R = 6371000
 
-##########################################################
-def haversine(lon1, lat1, lon2, lat2):
-    """Calculate the great circle distance (in meters) between two points
-    on the earth (specified in decimal degrees) """
-    lon1, lat1, lon2, lat2 = map(radians, [lon1, lat1, lon2, lat2])
-
-    dlon = lon2 - lon1
-    dlat = lat2 - lat1
-    a = sin(dlat/2)**2 + cos(lat1) * cos(lat2) * sin(dlon/2)**2
-    c = 2 * asin(sqrt(a))
-    return c * R
-
 ##########################################################
 def add_lengths(g):
     """Add length to the edges """
